from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django.test import TestCase
from django.contrib.contenttypes.models import ContentType

from adhesions.models import Adhesion
from .models import Service, ServiceType


class ServicesTests(TestCase):
    def setUp(self):
        user = User.objects.create_user('user', email='user@example.net', password='user')
        user = User.objects.create_user('admin', email='admin@example.net', password='admin', is_superuser=True)
        adhesion = Adhesion.objects.create(adherent_type=ContentType.objects.get_for_model(user), adherent_id=user.pk)
        stype = ServiceType.objects.create(name='VM')
        s1 = Service.objects.create(adhesion=adhesion, service_type=stype, label='Service 1')

    def test_service_list(self):
        self.client.login(username='user', password='user')
        response = self.client.get(reverse('service-list'))
        self.assertRedirects(response, reverse('login') + '?next=' + reverse('service-list'))
        self.client.login(username='admin', password='admin')
        response = self.client.get(reverse('service-list'))
        self.assertEqual(response.status_code, 200)
        self.assertContains(response, 'Service 1')
